################################################################
:mod:`.options.chart <highcharts_core.options.chart>`
################################################################

.. contents:: Module Contents
  :local:
  :depth: 3
  :backlinks: entry

.. toctree::
  :titlesonly:

  options_3d
  reset_zoom_button
  scrollable_plot_area
  zooming

-------------------------

.. module:: highcharts_core.options.chart

********************************************************************************************************************
class: :class:`ChartOptions <highcharts_core.options.chart.ChartOptions>`
********************************************************************************************************************

.. autoclass:: ChartOptions
  :members:
  :inherited-members:

  .. collapse:: Class Inheritance

    .. inheritance-diagram:: ChartOptions
      :top-classes: highcharts_core.metaclasses.HighchartsMeta
      :parts: -1

  |

-------------------------

********************************************************************************************************************
class: :class:`PanningOptions <highcharts_core.options.chart.PanningOptions>`
********************************************************************************************************************

.. autoclass:: PanningOptions
  :members:
  :inherited-members:

  .. collapse:: Class Inheritance

    .. inheritance-diagram:: PanningOptions
      :top-classes: highcharts_core.metaclasses.HighchartsMeta
      :parts: -1

  |

--------------

***************************
Sub-components
***************************

.. list-table::
  :widths: 60 40
  :header-rows: 1

  * - Module
    - Classes / Functions
  * - :mod:`.options.chart <highcharts_core.options.chart>`
    - :class:`ChartOptions <highcharts_core.options.chart.ChartOptions>`
      :class:`PanningOptions <highcharts_core.options.chart.PanningOptions>`
  * - :mod:`.options.chart.options_3d <highcharts_core.options.chart.options_3d>`
    - :class:`Options3D <highcharts_core.options.chart.options_3d.Options3D>`
      :class:`Frame <highcharts_core.options.chart.options_3d.Frame>`
      :class:`PanelOptions <highcharts_core.options.chart.options_3d.PanelOptions>`
  * - :mod:`.options.chart.reset_zoom_button <highcharts_core.options.chart.reset_zoom_button>`
    - :class:`ResetZoomButtonOptions <highcharts_core.options.chart.reset_zoom_button.ResetZoomButtonOptions>`
  * - :mod:`.options.chart.scrollable_plot_area <highcharts_core.options.chart.scrollable_plot_area>`
    - :class:`ScrollablePlotArea <highcharts_core.options.chart.scrollable_plot_area.ScrollablePlotArea>`
  * - :mod:`.options.chart.zooming <highcharts_core.options.chart.zooming>`
    - :class:`ZoomingOptions <highcharts_core.options.chart.zooming.ZoomingOptions>`
      :class:`MouseWheelOptions <highcharts_core.options.chart.zooming.MouseWheelOptions>`
